# About

See [this tutorial](https://github.com/mlcommons/ck/blob/master/docs/tutorials/modular-image-classification.md).

# Collaborative testing

## Windows 11

* CUDA 11.8; cuDNN 8.7.0; ONNX GPU 1.16.1

## Windows 10

* CUDA 11.6; cuDNN 8.6.0.96; ONNX GPU 1.13.1

## Ubuntu 22.04

* CUDA 11.3; ONNX 1.12.0
